@@ -1,6 +1,7 @@
 from jina.excepts import PeaFailToStart, GRPCServerError
 from fastapi.exceptions import HTTPException
 
+
 class FlowYamlParseException(Exception):
     """ Exception during loading yaml file for Flow creation"""
 
@@ -9,6 +10,10 @@ class FlowCreationException(Exception):
     """ Exception during flow creation via pods"""
 
 
+class FlowBadInputException(Exception):
+    """ Exception during loading Flow, no valid configuration"""
+
+
 class FlowStartException(Exception):
     """ Exception during flow start"""
 
